@@ -43,11 +43,21 @@ sub _set_storage {
   Scalar::Util::weaken($self->{storage});
 }
 
-sub no_of_subnodes { 4 }
+sub no_of_subnodes {
+  croak("no_of_subnodes needs to be implemented in a subclass");
+}
 
-sub coord_types { qw(double double double double) }
+sub no_of_dimensions {
+  croak("no_of_dimensions needs to be implemented in a subclass");
+}
 
-sub item_coord_types { qw(double double) }
+sub coord_types {
+  croak("coord_types needs to be implemented in a subclass");
+}
+
+sub item_coord_types {
+  croak("item_coord_types needs to be implemented in a subclass");
+}
 
 sub insert {
   croak("insert needs to be implemented in a subclass");
@@ -61,6 +71,10 @@ sub find_nodes_for {
   croak("find_nodes_for needs to be implemented in a subclass");
 }
 
+sub filter_items_in_rect {
+  croak("filter_items_in_rect needs to be implemented in a subclass");
+}
+
 1;
 __END__
 
@@ -77,18 +91,24 @@ Algorithm::SpatialIndex::Strategy - Base class for indexing strategies
 
 =head1 DESCRIPTION
 
+This is the base class for all algorithm implementations (I<Strategies>)
+in C<Algorithm::SpatialIndex>. Your implementation should probably not
+inherit from this class directly, but from either L<Algorithm::SpatialIndex::Strategy::2D>
+or L<Algorithm::SpatialIndex::Strategy::3D> depending on the dimensionality of
+your index.
+
 =head1 METHODS
 
 =head2 insert
 
 Inserts a new element into the index. Arguments:
-Element (not node!) integer id, Element x/y coordinates.
+Element (not node!) integer id, Element x/y (and possibly z) coordinates.
 
 Needs to be implemented in a subclass.
 
 =head2 find_node_for
 
-Given a pair of x/y coordinates, returns
+Given x/y (or x/y/z) coordinates, returns
 the L<Algorithm::SpatialIndex::Node>
 that contains the given point.
 
@@ -98,7 +118,7 @@ Needs to be implemented in a subclass.
 
 =head2 find_nodes_for
 
-Given two pairs of x/y coordinates, returns
+Given two sets of x/y (or x/y/z) coordinates, returns
 all L<Algorithm::SpatialIndex::Node>s that are completely
 or partly within the rectangle defined by the two points.
 
@@ -120,13 +140,18 @@ fresh object in the constructor.
 If your subcass implements this, it will be called on the
 in the constructor after initializing its storage attribute.
 
+=head2 no_of_dimensions
+
+A method returning the number of dimensions that the index handles.
+
+This is set to a default in the 2D/3D subclasses.
+
 =head2 no_of_subnodes
 
 Returns the number of subnodes per node. Required by the storage
 initialization.
 
-The default implementation returns 4 (for a quad tree).
-You may want to override that in your subclass.
+This is set to a default in the 2D/3D subclasses.
 
 =head2 coord_types
 
@@ -153,16 +178,41 @@ Valid coordinate types are:
 
 The integer types will be treated as C longs (likely 32bit).
 
-The default implementation returns
-C<qw(double double double double)> for storing two x/y
-coordinate pairs.
+This is set to a default in the 2D/3D subclasses.
 You may want to override that in your subclass.
 
 =head2 item_coord_types
 
 Same as coord_types, but indicating what's required for each
-item stored in the tree. Defaults to one X/Y coordinate pair
-of doubles.
+item stored in the tree.
+
+This is set to a default in the 2D/3D subclasses.
+
+=item filter_items_in_rect
+
+This method is implemented in L<Algorithm::SpatialIndex::Strategy::2D>
+and L<Algorithm::SpatialIndex::Strategy::3D> for their respective
+dimensionality. If you inherit from those classes, you will not
+have to reimplement this in your strategy implementation.
+
+Given the four or six coordinates of a rectangle (2D) or cuboid (3D)
+and one or more leaf node objects, this method fetches all items
+associated with the node(s) and returns all of those items
+that lie in the specified rectangle or cuboid.
+
+The rectangle/cuboid coordinates are expected to be sorted (thus
+the use of C<$xl, $yl> and C<$xu, $yu> instead of 1/2) in the
+example:
+
+  # 2D
+  my @items = $strategy->filter_items_in_rect($xl, $yl, $xu, $yu, $node1, $node2, ...);
+  
+  # 3D
+  my @items = $strategy->filter_items_in_rect(
+    $xl, $yl, $zl,
+    $xu, $yu, $zu,
+    $node1, $node2, ...
+  );
 
 =head1 AUTHOR
 
